summaryrefslogtreecommitdiff
path: root/extlib/DB/ifx.php
diff options
context:
space:
mode:
authorBrion Vibber <brion@pobox.com>2009-11-08 23:27:24 +0100
committerBrion Vibber <brion@pobox.com>2009-11-08 23:27:24 +0100
commitec6a38a62786c85e8ee30c5726ea81f82465b39d (patch)
tree31bb66f24f8fb4de55d9f6a21728278fcac804a1 /extlib/DB/ifx.php
parentc7961fe6dc033d1d40ab7d7f9bb994492ae4ea7b (diff)
parent104a47e4a2903f1c7ea73363a73cee12f0cf14ac (diff)
Merge branch '0.9.x' of gitorious.org:statusnet/mainline into 0.9.x
Diffstat (limited to 'extlib/DB/ifx.php')
-rw-r--r--extlib/DB/ifx.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/extlib/DB/ifx.php b/extlib/DB/ifx.php
index baa6f2867..dcb3dbd3e 100644
--- a/extlib/DB/ifx.php
+++ b/extlib/DB/ifx.php
@@ -147,7 +147,7 @@ class DB_ifx extends DB_common
/**
* The quantity of transactions begun
*
* {@internal While this is private, it can't actually be designated
* private in PHP 5 because it is directly accessed in the test suite.}}
*
* @var integer
@@ -328,7 +328,7 @@ class DB_ifx extends DB_common
* See DB_result::fetchInto() for more information.
*
* This method is not meant to be called directly. Use
* DB_result::fetchInto() instead. It can't be declared "protected"
* because DB_result is a separate object.
*
* @param resource $result the query result resource
@@ -387,7 +387,7 @@ class DB_ifx extends DB_common
* Gets the number of columns in a result set
*
* This method is not meant to be called directly. Use
* DB_result::numCols() instead. It can't be declared "protected"
* because DB_result is a separate object.
*
* @param resource $result PHP's query result resource
@@ -411,7 +411,7 @@ class DB_ifx extends DB_common
* Deletes the result set and frees the memory occupied by the result set
*
* This method is not meant to be called directly. Use
* DB_result::free() instead. It can't be declared "protected"
* because DB_result is a separate object.
*
* @param resource $result PHP's query result resource
@@ -555,7 +555,7 @@ class DB_ifx extends DB_common
*
* If analyzing a query result and the result has duplicate field names,
* an error will be raised saying
* <samp>can't distinguish duplicate field names</samp>.
*
* @param object|string $result DB_result object from a query or a
* string containing the name of a table.
@@ -604,7 +604,7 @@ class DB_ifx extends DB_common
$count = @ifx_num_fields($id);
if (count($flds) != $count) {
- return $this->raiseError("can't distinguish duplicate field names");
+ return $this->raiseError("cannot distinguish duplicate field names");
}
if ($this->options['portability'] & DB_PORTABILITY_LOWERCASE) {
@@ -147,7 +147,7 @@ class DB_ifx extends DB_common
* The quantity of transactions begun
*
- * {@internal While this is private, it can't actually be designated
+ * {@internal While this is private, it cannot actually be designated
* private in PHP 5 because it is directly accessed in the test suite.}}
*
@@ -328,7 +328,7 @@ class DB_ifx extends DB_common
*
* This method is not meant to be called directly. Use
- * DB_result::fetchInto() instead. It can't be declared "protected"
+ * DB_result::fetchInto() instead. It cannot be declared "protected"
* because DB_result is a separate object.
*
@@ -387,7 +387,7 @@ class DB_ifx extends DB_common
*
* This method is not meant to be called directly. Use
- * DB_result::numCols() instead. It can't be declared "protected"
+ * DB_result::numCols() instead. It cannot be declared "protected"
* because DB_result is a separate object.
*
@@ -411,7 +411,7 @@ class DB_ifx extends DB_common
*
* This method is not meant to be called directly. Use
- * DB_result::free() instead. It can't be declared "protected"
+ * DB_result::free() instead. It cannot be declared "protected"
* because DB_result is a separate object.
*
@@ -555,7 +555,7 @@ class DB_ifx extends DB_common
* If analyzing a query result and the result has duplicate field names,
* an error will be raised saying
- * <samp>can't distinguish duplicate field names</samp>.
+ * <samp>cannot distinguish duplicate field names</samp>.
*
* @param object|string $result DB_result object from a query or a